/*
 * See the NOTICE file distributed with this work for information
 * regarding copyright ownership.  This file is licensed
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.fabric3.spi.command;

/**
 * A registry of {@link CommandExecutor}s.
 *
 * @version $Rev: 121 $ $Date: 2007-05-28 17:02:50 -0700 (Mon, 28 May 2007) $
 */
public interface CommandExecutorRegistry {

    /**
     * Register the command executor
     *
     * @param type     the type of command the executor handles
     * @param executor the executor
     */
    <T extends Command> void register(Class<T> type, CommandExecutor<T> executor);

    /**
     * Dispatches a command to an exececutor.
     *
     * @param command the command to dispatch
     * @throws ExecutionException if there is an error executing the command
     */
    <T extends Command> void execute(T command) throws ExecutionException;
}
