/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.    
 */
package org.fabric3.spi.loader;

import javax.xml.stream.XMLStreamException;
import javax.xml.stream.XMLStreamReader;

/**
 * Deserializes an element from a StAX input stream.
 *
 * @version $Rev: 520 $ $Date: 2007-07-20 10:17:51 -0700 (Fri, 20 Jul 2007) $
 */
public interface StAXElementLoader<OUTPUT> {
    /**
     * Deserialize an element in an XML stream. When this method returns the stream will be positioned on the
     * corresponding END_ELEMENT.
     *
     * @param reader  the XML stream reader positioned on the applicable START_ELEMENT
     * @param context the context for the load operation
     * @return the deserialized object for that element
     * @throws LoaderException    if an error loading the type occurs
     * @throws XMLStreamException if an error reading the XML stream occurs
     */
    OUTPUT load(XMLStreamReader reader, LoaderContext context) throws XMLStreamException, LoaderException;
}
